<?php
/** Tarifit (Tarifit)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Agzennay
 * @author Aryaz
 * @author Dalinanir
 * @author Jose77
 * @author Urhixidur
 */

$messages = array(
# Dates
'sun'           => 'Asamas',
'mon'           => 'Aynas',
'tue'           => 'Asinas',
'wed'           => 'Akras',
'thu'           => 'Akwas',
'fri'           => 'Asimwas',
'sat'           => 'Asiḍyas',
'january'       => 'Yennayer',
'february'      => 'Yebrayer',
'march'         => 'Mares',
'april'         => 'Ibrir',
'may_long'      => 'May',
'june'          => 'Yunyu',
'july'          => 'Yulyuz',
'august'        => 'Ghuct',
'september'     => 'Cutanbir',
'october'       => 'Ktubar',
'november'      => 'Nuwanbir',
'december'      => 'Dujanbir',
'january-gen'   => 'Ynnayr',
'february-gen'  => 'Ybrayr',
'march-gen'     => 'Mars',
'april-gen'     => 'Ibrir',
'may-gen'       => 'May',
'june-gen'      => 'Yunyu',
'july-gen'      => 'Yulyuz',
'august-gen'    => 'Ghuct',
'september-gen' => 'Cutanbir',
'october-gen'   => 'Ktubar',
'november-gen'  => 'Nuwanbir',
'december-gen'  => 'Dujanbir',
'jan'           => 'Yennayer',
'feb'           => 'Yebrayer',
'mar'           => 'Mars',
'apr'           => 'Ybrir',
'may'           => 'May',
'jun'           => 'Yunyu',
'jul'           => 'Yulyuz',
'aug'           => 'Ghuct',
'sep'           => 'Cutanbir',
'oct'           => 'Ktubar',
'nov'           => 'Nuwanbir',
'dec'           => 'Dujanbir',

# Categories related messages
'category_header'        => 'Tasniwin di taggayt "$1"',
'subcategories'          => 'Tadu-ggayin',
'category-media-header'  => 'Media di category "$1"',
'category-empty'         => "''Taggayt a war dags bu ca n Tasna niɣ ca n umedia.''",
'listingcontinuesabbrev' => 'arni-d.',

'about'          => 'Xef',
'newwindow'      => '(Areẓm di tburjet d-tamaynut)',
'cancel'         => 'Sbdd',
'qbfind'         => 'Af',
'qbedit'         => 'Ẓṛeg',
'qbspecialpages' => 'Tudmawin Special',
'mytalk'         => 'Amsawal inu',
'navigation'     => 'Tagriwa',

'errorpagetitle'   => 'Anezri',
'returnto'         => 'Dwl ghar $1.',
'tagline'          => 'Zi {{SITENAME}}',
'help'             => 'Tallalt',
'search'           => 'Tarezzut',
'searchbutton'     => 'Rzu',
'go'               => 'Raḥ ɣa',
'searcharticle'    => 'Uyur',
'history'          => 'Amzruy n Tasna',
'history_short'    => 'Amezruy',
'printableversion' => 'Tanghelt n usiggez',
'permalink'        => 'Tamghunt iqqimen',
'edit'             => 'Ẓṛeg',
'create'           => 'Egg',
'editthispage'     => 'Ẓṛg tasna ya',
'delete'           => 'Kks',
'protect'          => 'Mstn',
'newpage'          => 'Tasna d-tamaynut',
'talkpage'         => 'Siwl xf tasna ya',
'talkpagelinktext' => 'Awal',
'personaltools'    => 'Imassen inu',
'talk'             => 'siwel',
'views'            => 'Timmeẓṛa',
'toolbox'          => 'Tanakat n imassen',
'otherlanguages'   => 'S tutlayin nneḍni',
'redirectedfrom'   => '(Itwasnnmd-d zi $1)',
'redirectpagesub'  => 'Tasna n (Redirect)',
'jumpto'           => 'Nḍu ghar:',
'jumptonavigation' => 'tagriwa',
'jumptosearch'     => 'tarezzut',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Awal xef {{SITENAME}}',
'aboutpage'            => 'Project:Awal xef',
'copyrightpage'        => '{{ns:project}}:izrefan ussenɣel',
'currentevents'        => 'Mayn itemsaren rux',
'currentevents-url'    => 'Project:mayn itmesaren ruxa',
'disclaimers'          => 'Ismigilen',
'disclaimerpage'       => 'Project:Asmigel amatu',
'edithelp'             => 'Tallalt deg uẓareg',
'edithelppage'         => 'Help:Aẓareg',
'helppage'             => 'Help:tallalt',
'mainpage'             => 'Tasna Tamezwarut',
'mainpage-description' => 'Tasna Tamzwarut',
'portal'               => 'Tawwart n timetti',
'portal-url'           => 'Project:tawwart n timetti',
'privacy'              => 'Tasertit n tusligi',
'privacypage'          => 'Project:Tasertit n tusligi',

'retrievedfrom'       => 'Itwarr-d zi "$1"',
'youhavenewmessages'  => 'Ghar-k / Ghar-m $1 ($2).',
'newmessageslink'     => 'tibratin timaynutin',
'newmessagesdifflink' => 'Taẓṛigt tanggarut',
'editsection'         => 'Ẓṛeg',
'editold'             => 'ẓṛeg',
'editlink'            => 'ẓṛg',
'viewsourcelink'      => 'ẓṛ aghbalu',
'editsectionhint'     => 'Ẓṛeg tigezmi: $1',
'toc'                 => 'Iktturn',
'showtoc'             => 'sskn-d',
'hidetoc'             => 'snuffar',
'site-rss-feed'       => 'Tilgha n RSS n $1',
'site-atom-feed'      => 'Talghut n Atom n $1',
'page-rss-feed'       => 'Asudem n RSS n "$1"',
'red-link-title'      => '$1 (tasna ur telli)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Tasna',
'nstab-user'     => 'Tasna n User',
'nstab-project'  => 'Tasna usenfar',
'nstab-image'    => 'Asatul',
'nstab-template' => 'Tamudmt',
'nstab-category' => 'Taggayt(category)',

# General errors
'badtitle'       => 'isem war icni ca',
'badtitletext'   => 'Isem n Tasna itexised war icni ca, ixwa, niɣ  isem n ajar-tutlayt niɣ ajar-wiki war icni ca.
teqqad ad yilli days ca n usekkil war itwagg deg isem .',
'viewsource'     => 'Ẓṛ aghbalu',
'viewsourcefor'  => 'i $1',
'viewsourcetext' => 'Tzemred a tẓerd u atsneɣled aɣbal n Tasna ya :',

# Login and logout pages
'yourname'                => 'Izwl-usqdac:',
'yourpassword'            => 'Tawalt n wadaf:',
'remembermypassword'      => 'ejj (login) inu deg uselkim a',
'login'                   => 'Adf',
'nav-login-createaccount' => 'Adef / egg amiḍan',
'loginprompt'             => "itxessa ad-teṭfed (''cookies'') bac ad tadfed ɣar {{SITENAME}}.",
'userlogin'               => 'Adf / egg amiḍan',
'logout'                  => 'Ufugh',
'userlogout'              => 'Ufugh',
'nologin'                 => "war ɣark login? '''$1'''.",
'nologinlink'             => 'Egg amiḍan',
'createaccount'           => 'Egg amiḍan',
'gotaccount'              => "ɣark  amiḍan? '''$1'''.",
'gotaccountlink'          => 'Adeff',
'yourrealname'            => 'isem n deṣṣaḥ :',
'prefs-help-realname'     => 'isem inec n deṣṣaḥ mala txesad waha .
mala tucit-id, ataf Lxdant inec a tetwassan ila inec.',
'loginsuccesstitle'       => 'Adaf icna',
'loginsuccess'            => "'''Qac tudeffed di {{SITENAME}} s \"\$1\".'''",
'nosuchuser'              => 'War illi ca n useqdac s isem a"$1".
xemm tirra , niɣ egg amiḍan d amaynu.',
'nosuchusershort'         => 'War illi ca n useqdac s isem a "<nowiki>$1</nowiki>".
xemm tirra.',
'nouserspecified'         => 'ixessa ad tuced isem n useqdac.',
'wrongpassword'           => 'Taguri n wadaf war tceni ca. Sideff tenni nican.',
'wrongpasswordempty'      => 'Taguri n wadaf i tucid texwa. Sideff tenni nican.',
'passwordtooshort'        => 'Taguri n wadaf inec war d tusi ca.
itxessat ad di-s tili {{PLURAL:$1|1 usekkil|$1 isekkilen}} u ad tili temṣebda x isem n useqdac inec.',
'mailmypassword'          => 'Sekk Taguri n wadaf di E-mail',
'passwordremindertitle'   => 'Taguri n wadaf tamaynut n ruxa waha {{SITENAME}}',
'passwordremindertext'    => 'Ca n ijj (teqqad ad yili d cekk, zi tansa IP a $1)
inna neɣ ada-s-ad nesekk Taguri n wadaf tamaynut i {{SITENAME}} ($4).
Taguri n wadaf n useqdac "$2" ruxa d "$3".
ixessa ad tadeffed bac ad tbeddeled ruxa.
ɣar {{PLURAL:$5|one day|$5 days}} at sala taguri n wadaf tamaynut .
mala war illi d cekk ur tawi x manaya , qim sexdam Taguri n wadaf inecc taqburt.',
'noemail'                 => 'War illi ca n e-mail ɣar useqdac a "$1".',
'passwordsent'            => 'Taguri n wadaf tamaynut twassekked i e-mail  "$1".
adeff-d xmi ɣa teṭfed.',
'eauthentsent'            => 'ijj n e-mail itwasekked ɣar e-mail nni.
zzat ma ca n e-mail nniḍen ma ad itwasekk ɣar umiḍan , ixessa ad tegged manayenni di e-mail, bac ad nessen ila qa amiḍan a inec.',

# Password reset dialog
'retypenew' => 'Ɛawd arri Taguri n wadaf tamaynut:',

# Edit page toolbar
'bold_sample'     => 'Tirra tizurarin',
'bold_tip'        => 'Tira tizurarin',
'italic_sample'   => 'Tirra titalyanin',
'italic_tip'      => 'Tira ifrghn.',
'link_sample'     => 'isem n tzedayt',
'link_tip'        => 'Tazdayt n dixl',
'extlink_sample'  => 'http://www.example.com isem n tezdayt',
'extlink_tip'     => 'Tazdayt n baṛṛa (qa tettud http:// prefix)',
'headline_sample' => 'Aḍris n ixf-isem',
'headline_tip'    => 'Aswir 2 n ixf-isem',
'math_sample'     => 'Egg ijj n formula da',
'math_tip'        => 'Mathematical formula (LaTeX)',
'nowiki_sample'   => 'Sideff da tirra bla taseddast(formatting) n wiki',
'nowiki_tip'      => 'Ur tawi x taseddast(formatting) n wiki',
'image_tip'       => 'Afaylu war-itmesebḍi',
'media_tip'       => 'Tazdayt ufaylu',
'sig_tip'         => 'Azewl(signature) inec ag ukud(time) .',
'hr_tip'          => 'Acariḍ aglawan',

# Edit pages
'summary'                => 'Tagḍwit:',
'subject'                => 'Abatu/izwl:',
'minoredit'              => 'Ta d taẓrigt d-tamẓeyant',
'watchthis'              => 'Ḥḍa tasna ya',
'savearticle'            => 'Xmml tasna',
'preview'                => 'Azar-ascan',
'showpreview'            => 'Ẓar Azar-ascan',
'showdiff'               => 'Ẓar mayn teẓṛegd.',
'anoneditwarning'        => "'''ɣark:''' war tudifd ca s isem inec.
Tansa n IP inac ad-teqqim deg umezruy n teẓṛigin n Tasna ya .",
'summary-preview'        => 'Azar-ascan n Tegḍwit:',
'blockedtext'            => "'''Isem useqdac niɣ tansa IP inecc tewabluca  .'''

iblocat  $1.
Maynzi ''$2''.

* Abluki ibda di: $8
* Ad ikemmel di: $6
* Abluki ig itwaxsen d: $7

Tzemred ad temsawaded ag $1 niɣ [[{{MediaWiki:Grouppage-sysop}}|administrator]] nniḍn bac ad tsiwled x ubluki a.
war tzemred ca ad ad tesxedmed 'e-mail this user' ɣar mala ca n e-mail illa ɣark di [[Special:Preferences|Isemyifiyen n umiḍan]] u war twabluki ca usexdem ines.
Tansa IP inecc n ruxa d $3, u ID icecc iteblukan d #$5.
maṛṛa manaya deg ujenna eggit di tabrat i ɣ-ad tsekked.",
'newarticle'             => '(Amaynu)',
'newarticletext'         => "Tdefar-d tazdayt n Tasna εad war telli .
bac ad tegged , arri di taflwit a swadday (xemm i [[{{MediaWiki:Helppage}}| Tasna n Tallalt]] i ineɣmisen ifruryen).
mala qacek da s ɣalaṭ waha, tecca di tbutunt n '''deffar''' di (browser) inec .",
'noarticletext'          => 'Rxxu ur din llint ca tira di tasna ya.
Tzmmard [[Special:Search/{{PAGENAME}}|rzu xf yizwl n tasna ya]] di tasniwin nnḍni,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} search the related logs],
nigh [{{fullurl:{{FULLPAGENAME}}|action=edit}} edit this page]</span>.',
'previewnote'            => "'''Wa d Azar-ascan waha;
tiẓṛigin εad war twaḥḍent!'''",
'editing'                => 'Aẓṛag di $1',
'editingsection'         => 'Aẓrag  di $1 (tigezmi)',
'copyrightwarning'       => "Maṛṛa tirra di {{SITENAME}} twaggent swadday i $2 (ẓar da $1).
mala war texsed tirra inac ad twaẓṛegent , ad twamsebḍant .
Ur ten-teg ca da.<br />
tjadjid-anɣ Ɛawt ila qa d cekk ig yuran manaya, niɣ tesneɣlet-id zi ca n uɣbal nniḍn d alelli.
'''UR SADDAF CA TIRRA ƔARSENT COPYRIGHTE BLA MA AD-IXES BAB-INES !'''",
'longpagewarning'        => "'''WARNING: Tasna ya dag-s $1 kilobyte ;
ca n imsuṭṭuyen(browsers) war zemren ca ad ẓṛegen tasniwin dag-sent 32 kb niɣ ktar.
ixessa ad ten tebḍid ɣar tigezmin(sections) d timeẓyanin.'''",
'templatesused'          => 'Timudmiwin itwaggen di Tasna ya:',
'templatesusedpreview'   => 'Timudmiwin igg itwasxdemen dg uzar-ascan a :',
'template-protected'     => '(twaḥḍa)',
'template-semiprotected' => '(semi-protected)',
'nocreatetext'           => '{{SITENAME}} war iqqim ca itejja iwdan ad ggen Tasniwin timaynutin.
tzemred addewred ɣar deffar, niɣ [[Special:UserLogin|Adeff niɣ egg amiḍan]].',
'recreate-deleted-warn'  => "'''Ɣark: qac tegged Tasna ig itwaksen zzat uya.'''

Ẓar aɣmis n umzruy n usfad n Tasna ya bac ad tsenad ma mliḥ ad tkemled aẓṛag.",

# History pages
'viewpagelogs'           => 'Ẓar aɣmis n Tasna ya',
'currentrev'             => 'Afegged n ruxa',
'revisionasof'           => 'Affegged am $1',
'revision-info'          => 'Afegged am $1 s $2', # Additionally available: $3: revision id
'previousrevision'       => '←Affegged n zik/zic',
'nextrevision'           => 'Afegged d amaynu→',
'currentrevisionlink'    => 'Afegged n rux',
'cur'                    => '',
'last'                   => 'anggaru',
'page_first'             => 'amzwaru',
'page_last'              => 'anggaru',
'histlegend'             => 'imṣebḍiyen: Sti(ixter) tibuttonin a ɣar wadday n tunɣilin n Tasna bac ad tsmzazal(compare).<br />
Tasarut: (cur) = imṣebḍiyen ag tunɣilt n ruxa,
(last) = imṣebḍiyen ag tunɣilt n zik, M = taẓrigt d-tamẓeyant.',
'history-fieldset-title' => 'Amzruy n min tẓṛid',
'histfirst'              => 'Amzwaru n marra',
'histlast'               => 'Anggaru n marra',

# Revision feed
'history-feed-item-nocomment' => '$1 ɣar $2', # user at time

# Revision deletion
'rev-delundel' => 'sken/ffer',

# Diffs
'history-title'           => 'Amezruy n ufegged n "$1"',
'difference'              => '(Amsebḍi jar ifeggiden)',
'lineno'                  => 'Tabrit $1:',
'compareselectedversions' => 'Smequdda tunɣilin a',
'editundo'                => 'kkes min ggigh',
'diff-multi'              => '({{PLURAL:$1|ijj n ufegged|$1 ifeggiden}} war ad twamlen ca.)',

# Search results
'searchresults'             => 'Tifellawin n tarezzut',
'searchresults-title'       => 'Tifellawin n tarezzut xef "$1"',
'searchsubtitle'            => 'Trezzud xef \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|marra tasniwin issentan s "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|marra tasniwin iteqqnen ghar "$1"]])',
'noexactmatch'              => "'''war telli ca n Tasna qarn-as \"\$1\".'''
tzemred ad [[:\$1|tarnid cek]].",
'prevn'                     => 'zzat $1',
'nextn'                     => 'deffar $1',
'viewprevnext'              => 'Ẓar ($1) ($2) ($3)',
'search-result-size'        => '$1 ({{PLURAL:$2|1 tawalt|$2 tiwalin}})',
'search-suggest'            => 'Ttugha txsd a tinid: $1',
'search-interwiki-caption'  => 'Awmatn n usnfar',
'search-interwiki-more'     => '(ujar)',
'search-mwsuggest-enabled'  => 's isumuren',
'search-mwsuggest-disabled' => 'walu isumuren',
'searchall'                 => 'maṛṛa',
'powersearch'               => 'Tarzzut tanmhazt',
'powersearch-legend'        => 'Tarzzut tanmhazt',

# Preferences page
'preferences'       => 'Ismyifiyn',
'mypreferences'     => 'Isemyifiyen inu',
'searchresultshead' => 'Tarzzut',

# Groups
'group-sysop' => 'Indbaln',
'group-all'   => '(maṛṛa)',

'grouppage-sysop' => '{{ns:project}}:inedbalen',

# User rights log
'rightslog' => 'Aghmis n talghut n izrfan n usqdac',

# Recent changes
'nchanges'                       => '$1 {{PLURAL:$1|tiẓṛegt|tiẓṛigin}}',
'recentchanges'                  => 'Tiẓṛigin tinggura',
'recentchanges-feed-description' => 'Bbar tiẓṛigin timayutin n wiki deg usudem(feed) a .',
'rcnote'                         => "Awadday {{PLURAL:$1|d '''1''' taẓṛigt|d '''$1''' tiẓṛigin tinggura}} deg {{PLURAL:$2|ass anggaru |'''$2''' ussan inggura}}, am di $5, $4.",
'rcnotefrom'                     => "ɣar wadday d tiẓṛigin zi '''$2''' (ar '''$1''' ).",
'rclistfrom'                     => 'Ẓar tiẓṛigin timaynutin ig ibeddan zi $1',
'rcshowhideminor'                => '$1 tiẓṛigin d-timeẓyanin',
'rcshowhidebots'                 => '$1 iroboten(robots)',
'rcshowhideliu'                  => '$1 users ig yudeffen',
'rcshowhideanons'                => '$1 users war twasnen',
'rcshowhidepatr'                 => 'Tiẓṛigin ig itwaẓrent di $1',
'rcshowhidemine'                 => '$1 tiẓṛigin inu',
'rclinks'                        => 'Ẓar $1 tiẓṛigin tinggura di $2 n ussan inggura <br />$3',
'diff'                           => 'imṣebḍan',
'hist'                           => 'Amezruy',
'hide'                           => 'Snuffar',
'show'                           => 'smmel-ad',
'minoreditletter'                => 'm',
'newpageletter'                  => 'N',
'boteditletter'                  => 'b',

# Recent changes linked
'recentchangeslinked'          => 'Isenfilen i yudsen wa',
'recentchangeslinked-title'    => 'Tiẓṛigin ssaɣant-id ɣar "$1"',
'recentchangeslinked-noresult' => 'War llint ca n tiẓṛigin di Tasna ya di lwaqt id-tucid .',
'recentchangeslinked-summary'  => "Ta d tabdart n isnfiln itwaggn drus zggwami di tasniwin id-iqqnen zg ict tasna nniḍn (nigh iqqnen ghar iwdan zi ca n taggayt).
Tasniwin di [[Special:Watchlist|your watchlist]] d '''tizurarin'''.",
'recentchangeslinked-page'     => 'Izwl n tasna:',

# Upload
'upload'            => 'Zdem-d asatul',
'uploadbtn'         => 'Zdem-d afaylu',
'uploadlogpage'     => 'Zdem-d aɣmis',
'filedesc'          => 'Asgbr',
'fileuploadsummary' => 'Asgbr:',
'uploadedimage'     => 'itwazdem-d "[[$1]]"',
'watchthisupload'   => 'Xm tasbtirt a',

# Special:ListFiles
'listfiles' => 'Tabdart n ifayluten',

# File description page
'filehist'                  => 'Amzruy n usatul',
'filehist-help'             => 'Tka di date/time bac ad tẓerd afaylu mamec ja d-itban di Lwaqt a .',
'filehist-deleteone'        => 'sfaḍ',
'filehist-current'          => 'aturaw',
'filehist-datetime'         => 'Azmz/Akud',
'filehist-user'             => 'Aseqdac',
'filehist-dimensions'       => 'Tisektiwin',
'filehist-filesize'         => 'Tiddi n ufaylu',
'filehist-comment'          => 'Tinit',
'imagelinks'                => 'Tizdayin',
'linkstoimage'              => '{{PLURAL:$1|Tasna ya teqn-ad|$1 Tasniwin a qnent-id}} ɣa ufaylu ya :',
'nolinkstoimage'            => 'war telli ca n Tasna teqqen-d ɣa ufaylu ya.',
'sharedupload'              => 'Wa d ijj ufaylu itwacrec jar aṭṭas n isenfaren(projects).', # $1 is the repo name, $2 is shareduploadwiki(-desc)
'noimage'                   => 'war illi ca n ufaylu s isem a , tzemred ad $1.',
'noimage-linktext'          => 'Zdem d ijj',
'uploadnewversion-linktext' => 'Zdem-d tunɣilt d-tamaynut n ufaylu a',

# File deletion
'filedelete-submit' => 'Sfaḍ',

# MIME search
'mimesearch' => 'tarezzut n MIME',

# List redirects
'listredirects' => 'Ẓar (redirects)',

# Unused templates
'unusedtemplates' => 'Timudmiwin war twasexedment',

# Random page
'randompage' => 'Tasna zi ṭṭarf',

# Random redirect
'randomredirect' => '(redirect) zi ṭṭarf',

# Statistics
'statistics' => 'tisiḍanin',

'disambiguations' => 'Tasniwin n usefhem',

'doubleredirects' => '(redirects) ɛɛawdent',

'brokenredirects'        => '(redirects) arẓent',
'brokenredirects-edit'   => '(arri)',
'brokenredirects-delete' => '(sfaḍ)',

'withoutinterwiki'        => 'Tasna bla tiẓdayin n tutlayt',
'withoutinterwiki-submit' => 'Smmrad',

'fewestrevisions' => 'Tasniwin s cwayt n ifeggiden',

# Miscellaneous special pages
'nbytes'                  => '$1 {{PLURAL:$1|atamḍan|itamḍanen}}',
'nlinks'                  => '$1 {{PLURAL:$1|Tazdayt|Tizdayin}}',
'nmembers'                => '$1 {{PLURAL:$1|amaslad|imasladen}}',
'lonelypages'             => 'Tasniwin tigujilin',
'uncategorizedpages'      => 'Tasniwin bla taggayt',
'uncategorizedcategories' => 'Taggayin bla taggayt',
'uncategorizedimages'     => 'ifayluten bla taggayt',
'uncategorizedtemplates'  => 'Timudmiwin bla taggayt',
'unusedcategories'        => 'Taggayin war twasxedment ca',
'unusedimages'            => 'ifayluten war twasxedmen',
'wantedcategories'        => 'Taggayin twaxsent',
'wantedpages'             => 'Tasniwin tewaxsent aṭṭas',
'mostlinked'              => 'Tasniwin iɣar-d-tewaqqenen aṭṭas',
'mostlinkedcategories'    => 'Taggayin iɣar-d tewaqqenen aṭṭas',
'mostlinkedtemplates'     => 'Timudmiwin iɣar-d tewaqqenen aṭṭas',
'mostcategories'          => 'Tasna iɣar llan taggayin aṭṭas',
'mostimages'              => 'ifayluten iɣar-d tewaqqenen aṭṭas',
'mostrevisions'           => 'Tasna iɣa illa aṭṭas qaɛ n ifeggiden',
'prefixindex'             => 'Afran s usekkil amẓwaru',
'shortpages'              => 'Tasniwin d-tiquḍaḍin',
'longpages'               => 'Tasniwin d-tizirarin',
'deadendpages'            => 'Tasniwin s tizdayin mmutent',
'protectedpages'          => 'Tasniwin ẓarqent',
'listusers'               => 'Tabdart n iseqdacen',
'newpages'                => 'Tasniwin timaynutin',
'ancientpages'            => 'Tasniwin n zik qqaε',
'move'                    => 'Smutti',
'movethispage'            => 'Smutti tasna ya',
'pager-newer-n'           => '{{PLURAL:$1|amynu 1|amynu $1}}',
'pager-older-n'           => '{{PLURAL:$1|aqbur 1|aqbur $1}}',

# Book sources
'booksources'    => 'Ighbula n udlis',
'booksources-go' => 'Uyur',

# Special:Log
'specialloguserlabel'  => 'Aseqdac:',
'speciallogtitlelabel' => 'isem:',
'log'                  => 'Aɣmis',
'all-logs-page'        => 'Maṛṛa iɣmisen',

# Special:AllPages
'allpages'       => 'Marra tasniwin',
'alphaindexline' => '$1 ɣa $2',
'nextpage'       => 'Tasna zzat ($1)',
'prevpage'       => 'Tasna zzat ($1)',
'allpagesfrom'   => 'Scan-d Tasniwin beddant zi:',
'allarticles'    => 'Marra tasniwin',
'allpagessubmit' => 'Uyur',
'allpagesprefix' => 'Ẓar Tasniwin s usekkil amzwaru:',

# Special:Categories
'categories' => 'Taggayin',

# Special:LinkSearch
'linksearch-ok' => 'Tarzzut',

# Special:ListUsers
'listusers-submit' => 'Smmrad',

# E-mail user
'emailuser' => 'Ssek E-mail i bnadm a',

# Watchlist
'watchlist'         => 'Tabdart uḥṭṭu inu',
'mywatchlist'       => 'Tabdart uḥṭṭu inu',
'watchlistfor'      => "(i '''$1''')",
'addedwatch'        => 'Temmarni ɣar Tabdart uḥṭṭu',
'addedwatchtext'    => 'Tasna "[[:$1]]" Temmarni ɣar [[Special:Watchlist|Tabdart uḥṭṭu]].',
'removedwatch'      => 'twakkes zi Tabdart uḥṭṭu',
'removedwatchtext'  => 'Tasna "[[:$1]]" twakkes zi [[Special:Watchlist|Tabdart uḥṭṭu inec]].',
'watch'             => 'Ḥḍa',
'watchthispage'     => 'Ḥḍa tasna ya',
'unwatch'           => 'Ur ḥṭṭa',
'watchlist-details' => '{{PLURAL:$1|$1 n Tasniwin|$1 n Tasniwin}} Twaẓrent bla Tasniwin n usiwl.',
'wlshowlast'        => 'Sseml-ad $1 tisεεatin $2 ussan $3 inggura',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Ḥṭṭigh...',
'unwatching' => 'Ur ḥṭṭigh...',

# Delete
'deletepage'            => 'Kks tasna',
'delete-legend'         => 'Sfaḍ',
'historywarning'        => 'ɣark: Tasna i txisd atekesd ɣars amzruy :',
'confirmdeletetext'     => 'Ur d ac iqqim walu a tsfḍed ict tasna ak marra amzruy nns.
Ma nican txsd a tggd manaya? Ma tssnd min ttggd? Ma ttggd manaya amc teqqaṛ  [[{{MediaWiki:Policy-url}}|tasrtit n Wiki]] ?',
'actioncomplete'        => 'Tiggawt tsala',
'deletedtext'           => '"<nowiki>$1</nowiki>" Twakkes.
Xemm $2 i tikkas timaynutin.',
'deletedarticle'        => 'twakkes "[[$1]]"',
'dellogpage'            => 'Aɣmis n uṣfaḍ',
'deletecomment'         => 'Ssebba:',
'deleteotherreason'     => 'Ca n ssebba nniḍn:',
'deletereasonotherlist' => 'Ssebba nniḍn',

# Rollback
'rollbacklink' => 'Sdwl ghar dffar',

# Protect
'protectlogpage'              => 'Aghmis n umstn',
'prot_1movedto2'              => '[[$1]] twaneql ɣa [[$2]]',
'protectcomment'              => 'Ssebba:',
'protectexpiry'               => 'Itsala:',
'protect_expiry_invalid'      => 'Akud n usali ur illi nican.',
'protect_expiry_old'          => 'Akud usali izri, idwl d amzruy.',
'protect-unchain'             => 'Arzem turagin n usnaqel',
'protect-text'                => "tzemred ad teẓṛed u atbedeld aswir n uḥeṭṭu n Tasna ya da '''<nowiki>$1</nowiki>'''.",
'protect-locked-access'       => "Amiḍan inecc war ɣars turagt bac ad ibeddel aswir n uḥeṭṭu n Tasna .
Aqa (settings) n Tasna '''$1''':",
'protect-cascadeon'           => 'Tasna ya tẓarq ruxa mayenzi tudef di {{PLURAL:$1|Tasna, iɣa illa|Tasniwin, iɣa illa}} aḥeṭṭu n usmuzzar(cascading protection).
Tezemred ad tbedeld aswir n uḥeṭṭu n Tasna ya, maca war itegg walu i uḥeṭṭu n usmuzzar(cascading protection).',
'protect-default'             => 'Ejj marra isqdacn.',
'protect-fallback'            => 'itxessat turagt n "$1"',
'protect-level-autoconfirmed' => 'Bluka iseqdacen war ɣasen ca amiḍan',
'protect-level-sysop'         => 'inedbalen waha',
'protect-summary-cascade'     => 'Asmuzzar',
'protect-expiring'            => 'itsala deg $1 (UTC)',
'protect-cascade'             => 'Ḥḍa Tasniwin i yudfen di Tasna ya (cascading protection)',
'protect-cantedit'            => 'war tezemred ca ad tbedeld iswiren n uḥeṭṭu n Tasna ya, mayenzi war ɣark turagt bac ad tẓṛegd.',
'protect-expiry-options'      => '2 tasεεat:2 hours,1 ass:1 day,3 ussan:3 days,1 amalass:1 week,2 imallasen:2 weeks,1 ayur:1 month,3 iyuren:3 months,6 iyuren:6 months,1 asggas:1 year,infinite:infinite', # display1:time1,display2:time2,...
'restriction-type'            => 'Turagt:',
'restriction-level'           => 'Aswir uskref:',

# Restrictions (nouns)
'restriction-edit' => 'Arri',

# Undelete
'undeletebtn'            => 'Ar-ad',
'undelete-search-submit' => 'Tarzzut',

# Namespace form on various pages
'namespace'      => 'Tallunt-izwel:',
'invert'         => 'Dren mayn testid (tixtard)',
'blanknamespace' => '(Amezwaru)',

# Contributions
'contributions' => 'Tiggawin n useqdac',
'mycontris'     => 'Tiggawin inu',
'contribsub2'   => 'i $1 ($2)',
'uctop'         => '(snnj)',
'month'         => 'Zg wayur (d zik):',
'year'          => 'Zg usggwas (d zik):',

'sp-contributions-newbies'     => 'Ẓar Tabdart n tiggawin n useqdac a deg umiḍan amaynu waha',
'sp-contributions-newbies-sub' => 'i imiḍan imaynuten',
'sp-contributions-blocklog'    => 'sbdd tabdart n talghut',
'sp-contributions-search'      => 'Arzu x tiggawin',
'sp-contributions-username'    => 'Tansa IP d isem useqdac:',
'sp-contributions-submit'      => 'Tarzzut',

# What links here
'whatlinkshere'           => 'Min iteqqnen ghar da',
'whatlinkshere-title'     => 'Tasniwin id-izedyen ɣar "$1"',
'whatlinkshere-page'      => 'Tasna:',
'linkshere'               => "Tasna ya tzedi ɣa '''[[:$1]]''':",
'nolinkshere'             => "war tlli ca n Tasna tqqen-d da '''[[:$1]]'''.",
'isredirect'              => 'Tasna n (redirect)',
'istemplate'              => 'Asidef',
'isimage'                 => 'amaqqan n tugna',
'whatlinkshere-prev'      => '{{PLURAL:$1|deffar|deffar $1}}',
'whatlinkshere-next'      => '{{PLURAL:$1|zzat|zzat $1}}',
'whatlinkshere-links'     => '← tizdayin',
'whatlinkshere-hidelinks' => '$1 timqqan',

# Block/unblock
'blockip'                  => 'Sbdd asqdac a',
'ipboptions'               => '2 n timirin:2 hours,1 n wass:1 day,3 n wussan:3 days,1 imalass:1 week,2 imallassn:2 weeks,1 wayur:1 month,3 wayurn:3 months,6 wayurn:6 months,1 asggwas:1 year,tartalla:infinite', # display1:time1,display2:time2,...
'ipblocklist'              => 'Tabdart n tansiwin IP d isemawen n iseqdacen ig iteblukan',
'ipblocklist-submit'       => 'Tarzzut',
'blocklink'                => 'Sbedd',
'unblocklink'              => 'Ṛẓem',
'contribslink'             => 'Tiggawin',
'blocklogpage'             => 'Ẓareqq aɣmis',
'blocklogentry'            => 'ibloka [[$1]] ar $2 $3',
'block-log-flags-nocreate' => 'timggit n imiḍanen imaynutn ttwasbdd',

# Move page
'movepagetext'     => "mala tesxedmed taseddast(form) a swadday, ad tessenaqled maṛṛa amzruy ines ɣar isem amaynu.
isem aqbur ad idwel d Tasna n (redirect) ɣar isem amaynu .
tzemred ad tebedled (redirects) bac ad qnent ɣar isem amezwaru s ufus.
mala war texsed ca, ẓar [[Special:DoubleRedirects|double]] niɣ [[Special:BrokenRedirects|broken redirects]].
xak ig illa ad txemmed ma tizdayin zedyent mani ig ixeṣ niɣ lla.

Tasna  '''war tniqil ca''' mala qaddin ca n Tasna s isem a amaynu, ɣar mala texwa niɣ d (redirect) u war ɣar-s bu ca n umzruy n uẓṛeg

mala amya, itxessa cekk ad tesnaqled s ufus mala txisd
'''ɣark!'''
manaya itebeddal Tasniwin, ixessa ad tesned mliḥ man tegged zzat ma ad tkemled manaya.",
'movepagetalktext' => "Tasna n usiwl ad twanqel ag Tasna ines '''ɣar mala:'''
*Ca n Tasna usiwl tella dini s isem a amaynu, niɣ
*Mala war tixtard tabelludt a swadday.

mala amya, itxessa cekk ad tesnaqled s ufus mala txisd.",
'movearticle'      => 'Smutti tasna:',
'newtitle'         => 'Ghar yizwl amaynu:',
'move-watch'       => 'Ẓar Tasna ya',
'movepagebtn'      => 'Snaqel Tasna',
'pagemovedsub'     => 'Asmutti itwagg',
'movepage-moved'   => '\'\'\'"$1" twanql ɣar "$2"\'\'\'', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
'articleexists'    => 'Tasna s isem a tella da, niɣ isem itucid war icni.
ixdar isem nniḍn.',
'talkexists'       => "'''Tasna twanql , maca Tasna n usiwl ins war twanqel ca maymmi qaddin ict nninḍ.
snaqlitent s ufus.'''",
'movedto'          => 'smutti ghar',
'movetalk'         => 'Snaqel Tasniwin n usiwl igg illan akid-s',
'1movedto2'        => '[[$1]] twaneql ɣa [[$2]]',
'movelogpage'      => 'Snaql aɣmis',
'movereason'       => 'Ssebba:',
'revertmove'       => 'sedwel',

# Export
'export' => 'Sekk tasniwin',

# Namespace 8 related
'allmessages' => 'inzan n unagraw',

# Thumbnails
'thumbnail-more'  => 'Smghar',
'thumbnail_error' => 'Error creating thumbnail: $1',

# Import log
'importlogpage' => 'Siri-d aɣmis',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Tasna inu',
'tooltip-pt-mytalk'               => 'Tasna usiwl inu',
'tooltip-pt-preferences'          => 'Isemyifiyen inu',
'tooltip-pt-watchlist'            => 'Tabdart n Tasniwin umi txmamd bac ad-ten teẓṛegd',
'tooltip-pt-mycontris'            => 'Tabdart n tiggawin inu',
'tooltip-pt-login'                => 'Neqqar ac adef s umiḍan nnek; maca malla texsed waha',
'tooltip-pt-logout'               => 'Ufugh',
'tooltip-ca-talk'                 => 'Amsawal xef tasna n ukettur',
'tooltip-ca-edit'                 => 'Tzemmared a tẓeṛged tasna ya.
Bbeẓ x ufeskar n uzar-timeẓṛi zzat i gha txemmled min turid',
'tooltip-ca-addsection'           => 'Arni tinit deg usiwl a.',
'tooltip-ca-viewsource'           => 'Tasna ya tẓarq. tzemred atẓred aɣbal ines.',
'tooltip-ca-history'              => 'Isughulen izrin n tasna ya.',
'tooltip-ca-protect'              => 'Ẓarq Tasna ya',
'tooltip-ca-delete'               => 'Kks Tasna ya',
'tooltip-ca-move'                 => 'Snaql Tasna a',
'tooltip-ca-watch'                => 'Arni tasna ya ghar tbdart uḥṭṭu nnc',
'tooltip-ca-unwatch'              => 'Kkes Tasna ya zi Tabdart uḥṭṭu inec',
'tooltip-search'                  => 'Rzu {{SITENAME}}',
'tooltip-search-go'               => 'Uyur ghar tasna s yizwel a s imant nnes malla tella',
'tooltip-search-fulltext'         => 'Rzu di tasniwin x waḍṛis a',
'tooltip-p-logo'                  => 'Tasbtirt Tamzwarut',
'tooltip-n-mainpage'              => 'Adef ghar tasna tamezwarut',
'tooltip-n-portal'                => 'Xf usenfar, mayn tzemmared a tegged, mani gha tafed tighawsiwin',
'tooltip-n-currentevents'         => 'Af tilgha n ugilal xf tmsarin titurawin',
'tooltip-n-recentchanges'         => 'Tabdart n isenfilen imaynuten di Wiki.',
'tooltip-n-randompage'            => 'Zdem ict tasna d tagacurant',
'tooltip-n-help'                  => 'Mani gha tessned',
'tooltip-t-whatlinkshere'         => 'Tabdart n marra tasniwin n Wiki i d-iteqqnen da',
'tooltip-t-recentchangeslinked'   => 'Isenfilen n drus zggwami di tasniwin i yetwaqqnen zi tasna ya',
'tooltip-t-contributions'         => 'Ẓar Tabdart n tiggawin n useqdac a',
'tooltip-t-emailuser'             => 'Sekk e-mail i bnadem a',
'tooltip-t-upload'                => 'Zdem-d isatulen',
'tooltip-t-specialpages'          => 'Tabdart n marra tasniwin tinemmezrayin',
'tooltip-t-print'                 => 'Tanghelt usiggez n tasna ya',
'tooltip-ca-nstab-main'           => 'Ẓeṛ tasna n ukettur',
'tooltip-ca-nstab-user'           => 'Ẓar Tasna n user',
'tooltip-ca-nstab-project'        => 'Ẓṛ tasna n usnfar',
'tooltip-ca-nstab-image'          => 'Ẓar Tasna n ufaylu',
'tooltip-ca-nstab-template'       => 'Ẓṛ tamudmt',
'tooltip-ca-nstab-help'           => 'Ẓar Tasna n tallalt',
'tooltip-ca-nstab-category'       => 'Ẓṛ tasna n taggayt',
'tooltip-minoredit'               => 'egg-itt d taẓṛigt tamẓyant',
'tooltip-save'                    => 'Xmml isnfiln nnk',
'tooltip-preview'                 => 'Ẓṛ mayn turid, zzat i t gha txmmld!',
'tooltip-diff'                    => 'Ẓar tiẓṛigin i teggid deg uḍṛiṣ a.',
'tooltip-compareselectedversions' => 'Ẓar imsebeḍiyen jar tunɣilin n Tasna ya.',
'tooltip-watch'                   => 'Arni Tasna ya ɣa Tabdart uḥṭṭu inec',

# Browsing diffs
'previousdiff' => '← imṣebḍan n zzat',
'nextdiff'     => 'Amṣebḍi zzat  →',

# Media information
'file-info-size'       => '($1 × $2 pixel, tiddi(size) n ufaylu: $3, anaw(type) n MIME: $4)',
'file-nohires'         => '<small>walu ca n resolution yemɣa x wa.</small>',
'svg-long-desc'        => '(Afaylu n SVG, dis $1 × $2 pixel, Tiddi n ufaylu: $3)',
'show-big-image'       => 'Resolution ameqran',
'show-big-image-thumb' => '<small>Tiddi n uzar-ascan: $1 × $2 pixel </small>',

# Special:NewFiles
'newimages' => 'Amewlaf n ifayluten imaynuten',
'ilsubmit'  => 'Tarzzut',

# Bad image list
'bad_image_list' => 'Tameslayt amya :

imagraden n tebdart (ɣarsent * deg umzwaru) ig iteten waha.
Tazdayt tamzwarut di tebrit ixessa atzdi ɣa afaylu war icni  .
kur tazdayt tdeffad a tmekkas .',

# Metadata
'metadata'          => 'Timuca Meta',
'metadata-help'     => 'Afaylu a ɣar-s tilɣa(informations) nniḍn, teqqad ad tili tarnitent camera niɣ scanner i tiggin.
mala afaylu a itwabeddel x mamec ja illa g umezwaru, ca n tilɣa teqqad ad ilint msebḍant x ufaylu amezwaru.',
'metadata-expand'   => 'Sicen-d tilɣa nnumɣarent',
'metadata-collapse' => 'Snuffar tilgha innumgharn',
'metadata-fields'   => 'Igran n EXIF metadata i yllan di tbrat a ad adfn di tasna n twlaft xmnni d-gha twḍa  tflwit n metadata.
Innḍni ad twaffrn dg umzwar.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength', # Do not translate list items

# External editor support
'edit-externally'      => 'Ẓṛeg afaylu a s usnas zi baṛṛa',
'edit-externally-help' => 'Xemm [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] i ktar n tilɣa(informations).',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'maṛṛa',
'imagelistall'     => 'maṛṛa',
'watchlistall2'    => 'marra',
'namespacesall'    => 'marra',
'monthsall'        => 'marra',

# Multipage image navigation
'imgmultigo' => 'Raḥ ɣa!',

# Table pager
'table_pager_limit_submit' => 'Raḥ ɣa',

# Watchlist editing tools
'watchlisttools-view' => 'Sicen ibeddilen i ssaɣan ɣar wayawya',
'watchlisttools-edit' => 'Ẓar d tẓṛegd Tabdart uḥṭṭu',
'watchlisttools-raw'  => 'Ẓṛeg Tabdart uḥṭṭu tamenzut',

# Special:Version
'version'              => 'Tunɣilt', # Not used as normal message but as header for the special page itself
'version-specialpages' => 'Tudmawin Special',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Tarzzut',

# Special:SpecialPages
'specialpages' => 'Tasniwin tinemmezrayin',

);
